@@ -20,6 +20,10 @@
 
 #include <octave/oct.h>
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 DEFUN_DLD (__errcore__, args, ,
   "-*- texinfo -*-\n\
 @deftypefn {Loadable Function} {@var{c} =} __errcore__ (@var{a}, @var{b})\n\
