@@ -18,16 +18,28 @@
 // program with any Open Source program, as defined by the Open Source
 // Initiative (www.opensource.org)
 
-#include <octave/config.h>
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+#include <octave/oct.h>
 #include <octave/error.h>
+#ifdef HAVE_OCTAVE_GRIPES_H
 #include <octave/gripes.h>
+#endif
+#ifdef HAVE_OCTAVE_ERRWARN_H
+#include <octave/errwarn.h>
+#endif
 #include <octave/mx-op-defs.h>
 
 #include "galois.h"
 #include "galoisfield.h"
 #include "galois-def.h"
 
-#include <octave/base-lu.cc>
+#ifdef  HAVE_OCTAVE_BASE_LU_H
+# include <octave/base-lu.cc>
+#else
+# include "base-lu.cc"
+#endif
 
 galois_field_list stored_galois_fields;
 
@@ -216,7 +228,7 @@ galois::operator += (const galois& a)
 
   if (nr != a_nr || nc != a_nc)
     {
-      gripe_nonconformant ("operator +=", nr, nc, a_nr, a_nc);
+      OCTAVE__ERR_NONCONFORMANT ("operator +=", nr, nc, a_nr, a_nc);
       return *this;
     }
 
@@ -252,7 +264,7 @@ galois::operator -= (const galois& a)
 
   if (nr != a_nr || nc != a_nc)
     {
-      gripe_nonconformant ("operator -=", nr, nc, a_nr, a_nc);
+      OCTAVE__ERR_NONCONFORMANT ("operator -=", nr, nc, a_nr, a_nc);
       return *this;
     }
 
@@ -518,7 +530,7 @@ elem_pow (const galois& a, const galois& b)
     {
       if (a_nr != b_nr || a_nc != b_nc)
         {
-          gripe_nonconformant ("operator .^", a_nr, a_nc, a_nr, a_nc);
+          OCTAVE__ERR_NONCONFORMANT ("operator .^", a_nr, a_nc, a_nr, a_nc);
           return galois ();
         }
 
@@ -549,7 +561,7 @@ elem_pow (const galois& a, const Matrix& b)
 
   if (a_nr != b_nr || a_nc != b_nc)
     {
-      gripe_nonconformant ("operator .^", a_nr, a_nc, b_nr, b_nc);
+      OCTAVE__ERR_NONCONFORMANT ("operator .^", a_nr, a_nc, b_nr, b_nc);
       return galois ();
     }
 
@@ -758,7 +770,7 @@ operator * (const galois& a, const galois& b)
     return product (a, b);
   else if (a_nc != b_nr)
     {
-      gripe_nonconformant ("operator *", a_nr, a_nc, b_nr, b_nc);
+      OCTAVE__ERR_NONCONFORMANT ("operator *", a_nr, a_nc, b_nr, b_nc);
       return galois ();
     }
   else
@@ -1303,7 +1315,7 @@ galois::solve (const galois& b, int& info,
 
           // Apply row interchanges to the right hand sides.
           //for (int j = 0; j < IP.length (); j++)
-          for (int j = IP.length ()-1; j >= 0; j--)
+          for (int j = IP.numel ()-1; j >= 0; j--)
             {
               int piv = IP(j);
               for (int i = 0; i < b_nc; i++)
@@ -1335,7 +1347,7 @@ galois::solve (const galois& b, int& info,
           Array<int> IP (fact.ipvt);
 
           // Apply row interchanges to the right hand sides.
-          for (int j = 0; j < IP.length (); j++)
+          for (int j = 0; j < IP.numel (); j++)
             {
               int piv = IP(j);
               for (int i = 0; i < b_nc; i++)
@@ -1420,7 +1432,7 @@ xdiv (const galois& a, const galois& b)
       int a_nr = a.rows ();
       int b_nr = b.rows ();
 
-      gripe_nonconformant ("operator /", a_nr, a_nc, b_nr, b_nc);
+      OCTAVE__ERR_NONCONFORMANT ("operator /", a_nr, a_nc, b_nr, b_nc);
       return galois ();
     }
 
@@ -1464,7 +1476,7 @@ xleftdiv (const galois& a, const galois& b)
       int a_nc = a.cols ();
       int b_nc = b.cols ();
 
-      gripe_nonconformant ("operator \\", a_nr, a_nc, b_nr, b_nc);
+      OCTAVE__ERR_NONCONFORMANT ("operator \\", a_nr, a_nc, b_nr, b_nc);
       return galois ();
     }
 
