@@ -14,7 +14,12 @@
 // along with this program; if not, see
 // <http://www.gnu.org/licenses/>.
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <octave/oct.h>
+#include <octave/utils.h>
 
 DEFUN_DLD (genqamdemod, args, ,
  "-*- texinfo -*-\n\
@@ -36,7 +41,7 @@ constellation mapping specified by the 1D vector @var{C}.\n\
 
   int nr1 (args(0).rows ());
   int nc1 (args(0).columns ());
-  int arg_is_empty1 = empty_arg ("genqamdemod", nr1, nc1);
+  int arg_is_empty1 = args(0).OV_ISEMPTY();
   Matrix y (nr1,nc1);
 
   int nr2 (args(1).rows ());
@@ -48,7 +53,7 @@ constellation mapping specified by the 1D vector @var{C}.\n\
   if (arg_is_empty1 > 0)
     return octave_value (Matrix ());
 
-  if (args(0).is_real_type () && args(1).is_real_type ())
+  if (args(0).OV_ISREAL () && args(1).OV_ISREAL ())
     { // Real-valued signal & constellation
       Matrix x (args(0).matrix_value ());
       ColumnVector constellation (args(1).vector_value ());
@@ -70,7 +75,7 @@ constellation mapping specified by the 1D vector @var{C}.\n\
             }
         }
     }
-  else if (args(0).is_complex_type () || args(1).is_complex_type ())
+  else if (args(0).OV_ISCOMPLEX () || args(1).OV_ISCOMPLEX ())
     { // Complex-valued input & constellation
       ComplexMatrix x (args(0).complex_matrix_value ());
       ComplexColumnVector constellation (args(1).complex_vector_value ());
