@@ -18,7 +18,10 @@
 // program with any Open Source program, as defined by the Open Source
 // Initiative (www.opensource.org)
 
-#include <octave/config.h>
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+#include <octave/oct.h>
 #include <octave/ops.h>
 #include <octave/ov-scalar.h>
 
@@ -79,6 +82,7 @@ DEFASSIGNOP (assign, galois, scalar)
   return octave_value ();
 }
 
+#ifndef DEFMETHOD_DLD
 void
 install_gm_s_ops (void)
 {
@@ -105,7 +109,34 @@ install_gm_s_ops (void)
 
   INSTALL_ASSIGNOP (op_asn_eq, octave_galois, octave_scalar, assign);
 }
-
+#else
+void
+install_gm_s_ops (octave::type_info& ti)
+{
+  INSTALL_BINOP_TI (ti, op_add, octave_galois, octave_scalar, add);
+  INSTALL_BINOP_TI (ti, op_sub, octave_galois, octave_scalar, sub);
+  INSTALL_BINOP_TI (ti, op_mul, octave_galois, octave_scalar, mul);
+  INSTALL_BINOP_TI (ti, op_div, octave_galois, octave_scalar, div);
+  INSTALL_BINOP_TI (ti, op_pow, octave_galois, octave_scalar, pow);
+  INSTALL_BINOP_TI (ti, op_ldiv, octave_galois, octave_scalar, ldiv);
+  INSTALL_BINOP_TI (ti, op_lt, octave_galois, octave_scalar, lt);
+  INSTALL_BINOP_TI (ti, op_le, octave_galois, octave_scalar, le);
+  INSTALL_BINOP_TI (ti, op_eq, octave_galois, octave_scalar, eq);
+  INSTALL_BINOP_TI (ti, op_ge, octave_galois, octave_scalar, ge);
+  INSTALL_BINOP_TI (ti, op_gt, octave_galois, octave_scalar, gt);
+  INSTALL_BINOP_TI (ti, op_ne, octave_galois, octave_scalar, ne);
+  INSTALL_BINOP_TI (ti, op_el_mul, octave_galois, octave_scalar, el_mul);
+  INSTALL_BINOP_TI (ti, op_el_div, octave_galois, octave_scalar, el_div);
+  INSTALL_BINOP_TI (ti, op_el_pow, octave_galois, octave_scalar, el_pow);
+  INSTALL_BINOP_TI (ti, op_el_ldiv, octave_galois, octave_scalar, el_ldiv);
+  INSTALL_BINOP_TI (ti, op_el_and, octave_galois, octave_scalar, el_and);
+  INSTALL_BINOP_TI (ti, op_el_or, octave_galois, octave_scalar, el_or);
+ 
+  INSTALL_CATOP_TI (ti, octave_galois, octave_scalar, gm_s);
+ 
+  INSTALL_ASSIGNOP_TI (ti, op_asn_eq, octave_galois, octave_scalar, assign);
+}
+#endif
 /*
 ;;; Local Variables: ***
 ;;; mode: C++ ***
