@@ -18,7 +18,10 @@
 // program with any Open Source program, as defined by the Open Source
 // Initiative (www.opensource.org)
 
-#include <octave/config.h>
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+#include <octave/oct.h>
 #include <octave/ops.h>
 #include <octave/ov-scalar.h>
 
@@ -83,6 +86,7 @@ DEFCATOP (s_gm, scalar, galois)
                                     ra_idx));
 }
 
+#ifndef DEFMETHOD_DLD
 void
 install_s_gm_ops (void)
 {
@@ -109,7 +113,34 @@ install_s_gm_ops (void)
 
   INSTALL_ASSIGNCONV (octave_scalar, octave_galois, octave_galois);
 }
-
+#else
+void
+install_s_gm_ops (octave::type_info& ti)
+{
+  INSTALL_BINOP_TI (ti, op_add, octave_scalar, octave_galois, add);
+  INSTALL_BINOP_TI (ti, op_sub, octave_scalar, octave_galois, sub);
+  INSTALL_BINOP_TI (ti, op_mul, octave_scalar, octave_galois, mul);
+  INSTALL_BINOP_TI (ti, op_div, octave_scalar, octave_galois, div);
+  INSTALL_BINOP_TI (ti, op_pow, octave_scalar, octave_galois, pow);
+  INSTALL_BINOP_TI (ti, op_ldiv, octave_scalar, octave_galois, ldiv);
+  INSTALL_BINOP_TI (ti, op_lt, octave_scalar, octave_galois, lt);
+  INSTALL_BINOP_TI (ti, op_le, octave_scalar, octave_galois, le);
+  INSTALL_BINOP_TI (ti, op_eq, octave_scalar, octave_galois, eq);
+  INSTALL_BINOP_TI (ti, op_ge, octave_scalar, octave_galois, ge);
+  INSTALL_BINOP_TI (ti, op_gt, octave_scalar, octave_galois, gt);
+  INSTALL_BINOP_TI (ti, op_ne, octave_scalar, octave_galois, ne);
+  INSTALL_BINOP_TI (ti, op_el_mul, octave_scalar, octave_galois, el_mul);
+  INSTALL_BINOP_TI (ti, op_el_div, octave_scalar, octave_galois, el_div);
+  INSTALL_BINOP_TI (ti, op_el_pow, octave_scalar, octave_galois, el_pow);
+  INSTALL_BINOP_TI (ti, op_el_ldiv, octave_scalar, octave_galois, el_ldiv);
+  INSTALL_BINOP_TI (ti, op_el_and, octave_scalar, octave_galois, el_and);
+  INSTALL_BINOP_TI (ti, op_el_or, octave_scalar, octave_galois, el_or);
+ 
+  INSTALL_CATOP_TI (ti, octave_scalar, octave_galois, s_gm);
+ 
+  INSTALL_ASSIGNCONV_TI (ti, octave_scalar, octave_galois, octave_galois);
+}
+#endif
 /*
 ;;; Local Variables: ***
 ;;; mode: C++ ***
