@@ -18,10 +18,18 @@
 // program with any Open Source program, as defined by the Open Source
 // Initiative (www.opensource.org)
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <octave/oct.h>
 
-#define COL_MAJ(N) (N / (SIZEOF_INT << 3))
-#define COL_MIN(N) (N % (SIZEOF_INT << 3))
+#ifndef SIZEOF_INT
+  #define SIZEOF_INT int(sizeof(int))
+#endif
+
+#define COL_MAJ(N) (N / (sizeof (int) << 3))
+#define COL_MIN(N) (N % (sizeof (int) << 3))
 
 Array<int>
 get_errs (const int& nmin, const int& nmax, const int &nerrs)
@@ -94,7 +102,7 @@ this to reference each row of @var{t}.\n\
   if (m > (int)(sizeof (int) << 3))
     {
       error ("syndtable: codeword minus message length must be less than %d",
-             (sizeof (int) << 3));
+             (int)(sizeof (int) << 3));
       return retval;
     }
 
